Changelog
=========

Notable changes between releases.

0.1.0 (2014-05-31)
------------------

**Features**

- Provide a repository abstraction
- Support the Git command's simplest subcommands (clone, update)
- Support Github and Bitbucket hosts
- Provide a utility to map between import paths and repositories
